@@ -18,11 +18,11 @@ Text::Diff::FormattedHTML - Generate a colorful HTML diff of strings/files.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -197,6 +197,8 @@ sub _internal_diff {
             my $out = "";
             my ($class, $ln, $rn, $l, $r) = @_;
             if ($l eq $r) {
+                $class eq "disc_a" && ($class = "disc_a del";
+                $class eq "disc_b" && ($class = "disc_b ins";
                 $out .= sprintf("<tr class='%s'><td>%s</td><td>%s</td><td>%s</td></tr>\n",
                                 $class, $ln, $rn, $l);
             } else {
@@ -258,9 +260,12 @@ Alberto Simoes, C<< <ambs at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-text-diff-formattedhtml at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Text-Diff-FormattedHTML>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to
+C<bug-text-diff-formattedhtml at rt.cpan.org>, or through the web
+interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Text-Diff-FormattedHTML>.
+I will be notified, and then you'll automatically be notified of
+progress on your bug as I make changes.
 
 
 
